searchData={"items":[{"type":"module","title":"TailwindVariants","doc":"Provides a variant system for TailwindCSS in Elixir applications.\n\nThis library allows you to create components with variants, slots, and more,\nsimilar to the JavaScript tailwind-variants library.","ref":"TailwindVariants.html"},{"type":"function","title":"TailwindVariants.tv/1","doc":"Creates a tailwind-variants component with the given options.","ref":"TailwindVariants.html#tv/1"},{"type":"function","title":"Options - TailwindVariants.tv/1","doc":"* `:base` - Base classes for the component\n* `:slots` - Map of slot names to their classes\n* `:variants` - Map of variant names to their values\n* `:default_variants` - Map of variant names to their default values\n* `:compound_variants` - List of compound variants\n* `:compound_slots` - List of compound slots\n* `:extend` - Another component to extend\n* `:config` - Configuration options","ref":"TailwindVariants.html#tv/1-options"},{"type":"function","title":"Examples - TailwindVariants.tv/1","doc":"iex> component = tv(%{base: \"font-medium text-white\"})\n    iex> component.base\n    \"font-medium text-white\"\n\n    iex> component = tv(%{\n    ...>   base: \"font-medium text-white\",\n    ...>   variants: %{\n    ...>     color: %{\n    ...>       primary: \"bg-blue-500\",\n    ...>       secondary: \"bg-purple-500\"\n    ...>     }\n    ...>   }\n    ...> })\n    iex> component.variants.color.primary\n    \"bg-blue-500\"","ref":"TailwindVariants.html#tv/1-examples"},{"type":"function","title":"TailwindVariants.tw/2","doc":"Applies props to a component to generate class names.","ref":"TailwindVariants.html#tw/2"},{"type":"function","title":"Parameters - TailwindVariants.tw/2","doc":"* `component` - A component created with `tv/1`\n* `props` - A map of props to apply to the component","ref":"TailwindVariants.html#tw/2-parameters"},{"type":"function","title":"Returns - TailwindVariants.tw/2","doc":"* A string of class names (if no slots are defined)\n* A map of slot functions (if slots are defined)","ref":"TailwindVariants.html#tw/2-returns"},{"type":"function","title":"Examples - TailwindVariants.tw/2","doc":"iex> component = tv(%{base: \"font-medium text-white\"})\n    iex> tw(component)\n    \"font-medium text-white\"\n\n    iex> component = tv(%{\n    ...>   base: \"font-medium\",\n    ...>   variants: %{\n    ...>     color: %{\n    ...>       primary: \"bg-blue-500\",\n    ...>       secondary: \"bg-purple-500\"\n    ...>     }\n    ...>   }\n    ...> })\n    iex> tw(component, %{color: \"primary\"})\n    \"font-medium bg-blue-500\"","ref":"TailwindVariants.html#tw/2-examples"},{"type":"function","title":"TailwindVariants.variant_options/1","doc":"Returns a map of all available variants and their possible values for a component.\nUseful for generating documentation or validation.","ref":"TailwindVariants.html#variant_options/1"},{"type":"function","title":"Example - TailwindVariants.variant_options/1","doc":"iex> button = tv(%{variants: %{color: %{primary: \"\", secondary: \"\"}}})\n    iex> variant_options(button)\n    %{color: [:primary, :secondary]}","ref":"TailwindVariants.html#variant_options/1-example"},{"type":"module","title":"TailwindVariants.Application","doc":"","ref":"TailwindVariants.Application.html"},{"type":"function","title":"TailwindVariants.Application.start/2","doc":"","ref":"TailwindVariants.Application.html#start/2"},{"type":"module","title":"TailwindVariants.Component","doc":"Represents a tailwind-variants component.","ref":"TailwindVariants.Component.html"},{"type":"module","title":"TailwindVariants.Config","doc":"Configuration module for TailwindVariants.","ref":"TailwindVariants.Config.html"},{"type":"function","title":"TailwindVariants.Config.config/1","doc":"Returns the merged configuration.","ref":"TailwindVariants.Config.html#config/1"},{"type":"module","title":"TailwindVariants.Utils","doc":"Utility functions for manipulating class names.","ref":"TailwindVariants.Utils.html"},{"type":"function","title":"TailwindVariants.Utils.atomize_keys/1","doc":"Convert a map to atom keys.\nWarning that this is not a recursive function and is unsafe and could\nresult in a denial of service attack if you exceed the atom limit.","ref":"TailwindVariants.Utils.html#atomize_keys/1"},{"type":"function","title":"Examples - TailwindVariants.Utils.atomize_keys/1","doc":"iex> atomize_keys(%{\"name\" => \"John\", \"age\" => 30})\n    %{name: \"John\", age: 30}\n\n    iex> atomize_keys(%{\"user\" => %{\"name\" => \"John\", \"age\" => 30}})\n    %{user: %{name: \"John\", age: 30}}","ref":"TailwindVariants.Utils.html#atomize_keys/1-examples"},{"type":"function","title":"TailwindVariants.Utils.join_class_names/1","doc":"Joins class names, handling nil, empty strings, and nested arrays.","ref":"TailwindVariants.Utils.html#join_class_names/1"},{"type":"function","title":"Examples - TailwindVariants.Utils.join_class_names/1","doc":"iex> join_class_names([\"font-bold\", \"text-lg\"])\n    \"font-bold text-lg\"\n\n    iex> join_class_names([\"font-bold\", nil, \"text-lg\"])\n    \"font-bold text-lg\"\n\n    iex> join_class_names([\"font-bold\", [\"text-lg\", \"p-4\"]])\n    \"font-bold text-lg p-4\"","ref":"TailwindVariants.Utils.html#join_class_names/1-examples"},{"type":"function","title":"TailwindVariants.Utils.merge_class_names/2","doc":"Merges class names using tw_merge if enabled in config.","ref":"TailwindVariants.Utils.html#merge_class_names/2"},{"type":"function","title":"Examples - TailwindVariants.Utils.merge_class_names/2","doc":"iex> merge_class_names([\"p-4\", \"p-6\"], %{tw_merge: true})\n    \"p-6\"\n\n    iex> merge_class_names([\"p-4\", \"p-6\"], %{tw_merge: false})\n    \"p-4 p-6\"","ref":"TailwindVariants.Utils.html#merge_class_names/2-examples"},{"type":"function","title":"TailwindVariants.Utils.stringify_keys/1","doc":"Recursively converts all keys in a map to strings.\nHandles nested maps and lists of maps.","ref":"TailwindVariants.Utils.html#stringify_keys/1"},{"type":"function","title":"Examples - TailwindVariants.Utils.stringify_keys/1","doc":"iex> stringify_keys(%{name: \"John\", age: 30})\n    %{\"name\" => \"John\", \"age\" => 30}\n\n    iex> stringify_keys(%{user: %{name: \"John\", age: 30}})\n    %{\"user\" => %{\"name\" => \"John\", \"age\" => 30}}","ref":"TailwindVariants.Utils.html#stringify_keys/1-examples"},{"type":"function","title":"TailwindVariants.Utils.try_existing_atom/1","doc":"Convert a string to an atom.","ref":"TailwindVariants.Utils.html#try_existing_atom/1"},{"type":"extras","title":"Tailwind Variants","doc":"tailwind-variants \n   \n \n \n  The  power  of Tailwind combined with a  first-class  variant API.  \n  A port of the popular  tailwind-variants  library to Elixir, providing a first-class variant API for TailwindCSS in Elixir applications.","ref":"readme.html"},{"type":"extras","title":"Features - Tailwind Variants","doc":"- First-class variant API\n- Slots support\n- Composition support\n- Automatic conflict resolution\n- Compound variants\n- Type-safe variants\n- Simple class merging utility","ref":"readme.html#features"},{"type":"extras","title":"Installation - Tailwind Variants","doc":"Add `tailwind_variants` to your list of dependencies in `mix.exs`:\n\n```elixir\ndef deps do\n  [\n    {:tailwind_variants, \"~> 0.1\"},\n    {:tw_merge, \"~> 0.1.1\"} # Required for class merging\n  ]\nend\n```","ref":"readme.html#installation"},{"type":"extras","title":"Usage - Tailwind Variants","doc":"","ref":"readme.html#usage"},{"type":"extras","title":"Basic Example - Tailwind Variants","doc":"```elixir\nimport TailwindVariants, only: [tv: 1, tw: 2]\n\nbutton = tv(%{\n  base: \"font-medium bg-blue-500 text-white rounded-full active:opacity-80\",\n  variants: %{\n    color: %{\n      primary: \"bg-blue-500 text-white\",\n      secondary: \"bg-purple-500 text-white\"\n    },\n    size: %{\n      sm: \"text-sm\",\n      md: \"text-base\",\n      lg: \"px-4 py-3 text-lg\"\n    }\n  },\n  compound_variants: [\n    %{\n      size: [\"sm\", \"md\"],\n      class: \"px-3 py-1\"\n    }\n  ],\n  default_variants: %{\n    size: \"md\",\n    color: \"primary\"\n  }\n})\n\n# Use in Phoenix/LiveView\n \n  Click me\n \n```","ref":"readme.html#basic-example"},{"type":"extras","title":"With Slots - Tailwind Variants","doc":"Slots allows you to separate a component into multiple parts.\n\n```elixir\nimport TailwindVariants, only: [tv: 1, tw: 2]\n\ncard = tv(%{\n  slots: %{\n    base: \"md:flex bg-slate-100 rounded-xl p-8 md:p-0 dark:bg-gray-900\",\n    avatar: \"w-24 h-24 md:w-48 md:h-auto md:rounded-none rounded-full mx-auto drop-shadow-lg\",\n    wrapper: \"flex-1 pt-6 md:p-8 text-center md:text-left space-y-4\",\n    description: \"text-md font-medium\",\n    info_wrapper: \"font-medium\",\n    name: \"text-sm text-sky-500 dark:text-sky-400\",\n    role: \"text-sm text-slate-700 dark:text-slate-500\"\n  }\n})\n\n# Destructure the slots\n%{base: base, avatar: avatar, wrapper: wrapper, description: description,\n  info_wrapper: info_wrapper, name: name, role: role} = tw(card)\n```\n\n```html\n# Use in Phoenix/LiveView\n \n   \n   \n     \n       \n        \"Tailwind variants allows you to reduce repeated code in your project\n        and make it more readable.\"\n       \n     \n     \n       Zoey Lang \n       Full-stack developer \n     \n   \n \n```","ref":"readme.html#with-slots"},{"type":"extras","title":"Variants with Slots - Tailwind Variants","doc":"You can also add variants to components with slots.\n\n```elixir\nimport TailwindVariants, only: [tv: 1, tw: 2]\n\nalert = tv(%{\n  slots: %{\n    root: \"rounded py-3 px-5 mb-4\",\n    title: \"font-bold mb-1\",\n    message: \"\"\n  },\n  variants: %{\n    variant: %{\n      outlined: %{\n        root: \"border\"\n      },\n      filled: %{\n        root: \"\"\n      }\n    },\n    severity: %{\n      error: \"\",\n      success: \"\"\n    }\n  },\n  compound_variants: [\n    %{\n      variant: \"outlined\",\n      severity: \"error\",\n      class: %{\n        root: \"border-red-700 dark:border-red-500\",\n        title: \"text-red-700 dark:text-red-500\",\n        message: \"text-red-600 dark:text-red-500\"\n      }\n    },\n    %{\n      variant: \"outlined\",\n      severity: \"success\",\n      class: %{\n        root: \"border-green-700 dark:border-green-500\",\n        title: \"text-green-700 dark:text-green-500\",\n        message: \"text-green-600 dark:text-green-500\"\n      }\n    },\n    %{\n      variant: \"filled\",\n      severity: \"error\",\n      class: %{\n        root: \"bg-red-100 dark:bg-red-800\",\n        title: \"text-red-900 dark:text-red-50\",\n        message: \"text-red-700 dark:text-red-200\"\n      }\n    },\n    %{\n      variant: \"filled\",\n      severity: \"success\",\n      class: %{\n        root: \"bg-green-100 dark:bg-green-800\",\n        title: \"text-green-900 dark:text-green-50\",\n        message: \"text-green-700 dark:text-green-200\"\n      }\n    }\n  ],\n  default_variants: %{\n    variant: \"filled\",\n    severity: \"success\"\n  }\n})\n\n%{root: root, message: message, title: title} = tw(alert, %{severity: \"error\", variant: \"outlined\"})\n```\n\nThen in your LiveView:\n\n```html\n \n   Oops, something went wrong \n   \n    Something went wrong saving your changes. Try again later.\n   \n \n```","ref":"readme.html#variants-with-slots"},{"type":"extras","title":"Component Composition - Tailwind Variants","doc":"You can compose components using the `extend` parameter:\n\n```elixir\nimport TailwindVariants, only: [tv: 1, tw: 2]\n\nbase_button = tv(%{\n  base: \"font-semibold dark:text-white py-1 px-3 rounded-full active:opacity-80 bg-zinc-100 hover:bg-zinc-200 dark:bg-zinc-800 dark:hover:bg-zinc-800\"\n})\n\nbuy_button = tv(%{\n  extend: base_button,\n  base: \"text-sm text-white rounded-lg shadow-lg uppercase tracking-wider bg-blue-500 hover:bg-blue-600 shadow-blue-500/50 dark:bg-blue-500 dark:hover:bg-blue-600\"\n})\n```\n\n```html\n# Use in Phoenix/LiveView\n \n   Button \n   Buy button \n \n```","ref":"readme.html#component-composition"},{"type":"extras","title":"Compound Slots - Tailwind Variants","doc":"You can define styles that apply to specific slots when certain conditions are met:\n\n```elixir\nimport TailwindVariants, only: [tv: 1, tw: 2]\n\nbutton = tv(%{\n  slots: %{\n    base: \"flex items-center\",\n    icon: \"w-4 h-4\",\n    text: \"ml-2\"\n  },\n  variants: %{\n    size: %{\n      sm: %{\n        icon: \"w-3 h-3\",\n        text: \"text-xs\"\n      },\n      lg: %{\n        icon: \"w-5 h-5\",\n        text: \"text-lg\"\n      }\n    }\n  },\n  compound_slots: [\n    %{\n      slots: [\"icon\", \"text\"],\n      size: \"lg\",\n      class: \"font-bold\" # This will apply to both icon and text slots when size is \"lg\"\n    }\n  ]\n})\n\n%{base: base, icon: icon, text: text} = tw(button, %{size: \"lg\"})\n```\n\n```html\n# Use in Phoenix/LiveView\n \n   <!-- SVG contents --> \n   Click me \n \n```","ref":"readme.html#compound-slots"},{"type":"extras","title":"Class Merging - Tailwind Variants","doc":"The `tw` function can also be used as a class merging utility:\n\n```elixir\nimport TailwindVariants, only: [tw: 2]\n\n# Simple class string merging\ntw(\"bg-red-500\", \"p-4 bg-blue-500\") # => \"p-4 bg-blue-500\" (blue-500 overrides red-500)\n\n# With conditional classes\ntw([\"flex\", is_active && \"bg-blue-500\"]) # => \"flex bg-blue-500\" (if is_active is true)\n\n# With a class override\ntw(\"base-classes\", %{class: \"override-classes\"}) # => \"base-classes override-classes\"\n```\n\n```html\n# In Phoenix templates\n \n  Content with merged classes\n \n```","ref":"readme.html#class-merging"},{"type":"extras","title":"API Reference - Tailwind Variants","doc":"","ref":"readme.html#api-reference"},{"type":"extras","title":"tv/1 - Tailwind Variants","doc":"Creates a tailwind-variants component:\n\n```elixir\ntv(options)\n```\n\n#### Parameters\n\nThe `options` argument is a map with the following keys:\n\n- `base` (optional): The base styles for the component\n- `slots` (optional): A map of slot names to their styles\n- `variants` (optional): A map of variant names to their values\n- `default_variants` (optional): A map of variant names to their default values\n- `compound_variants` (optional): A list of compound variants\n- `compound_slots` (optional): A list of compound slots\n- `extend` (optional): Another component to extend\n- `config` (optional): Configuration options\n\n#### Return Value\n\nReturns a component that can be used with `tw/2`.","ref":"readme.html#tv-1"},{"type":"extras","title":"tw/2 - Tailwind Variants","doc":"A multi-purpose function that works with components and class strings:\n\n```elixir\ntw(component_or_classes, props_or_more_classes \\\\ %{})\n```\n\n#### Parameters\n\nWhen used with a component:\n- `component`: A component created with `tv/1`\n- `props`: A map of props to apply to the component\n\nWhen used for class merging:\n- `classes`: A string or list of classes to merge\n- `more_classes`: Additional classes to merge (string, list, or map with `:class` key)\n\n#### Return Value\n\nWhen used with a component:\n- A string of class names (if no slots are defined)\n- A map of slot functions (if slots are defined)\n\nWhen used for class merging:\n- A string of merged class names\n\n#### Examples\n\n```elixir\n# With a component\ntw(button, %{color: :primary})  # => \"base-classes color-variant-classes\"\n\n# With a component that has slots\nslots = tw(card, %{variant: \"outlined\"})\nslots.tw(header)  # => \"header-classes outlined-variant-classes\"\n\n# For class merging\ntw(\"text-lg\", \"font-bold\")  # => \"text-lg font-bold\"\ntw([\"flex\", is_active && \"bg-blue-500\"])  # => \"flex bg-blue-500\" (if is_active is true)\n```","ref":"readme.html#tw-2"},{"type":"extras","title":"Configuration - Tailwind Variants","doc":"","ref":"readme.html#configuration"},{"type":"extras","title":"TwMerge Configuration - Tailwind Variants","doc":"If you need to customize the TwMerge behavior, you can pass a configuration in your component:\n\n```elixir\nbutton = tv(%{\n  base: \"...\",\n  config: %{\n    tw_merge: true, # Set to false to disable TwMerge and use simple joining\n  }\n})\n```","ref":"readme.html#twmerge-configuration"},{"type":"extras","title":"Variant Options - Tailwind Variants","doc":"To get a list of all available variants and their possible values:\n\n```elixir\nimport TailwindVariants, only: [tv: 1, variant_options: 1]\n\nbutton = tv(%{\n  variants: %{\n    color: %{primary: \"\", secondary: \"\"},\n    size: %{sm: \"\", md: \"\", lg: \"\"}\n  }\n})\n\nvariant_options(button)  # => %{color: [:primary, :secondary], size: [:sm, :md, :lg]}\n```","ref":"readme.html#variant-options"},{"type":"extras","title":"Contributing - Tailwind Variants","doc":"Contributions are welcome! Please feel free to submit a Pull Request.","ref":"readme.html#contributing"},{"type":"extras","title":"License - Tailwind Variants","doc":"This project is licensed under the MIT License - see the LICENSE file for details.","ref":"readme.html#license"},{"type":"extras","title":"Acknowledgements - Tailwind Variants","doc":"This library is an Elixir port of the JavaScript [tailwind-variants](https://www.tailwind-variants.org/) library created by Junior Garcia (@jrgarciadev) and Tianen Pang (@tianenpang).","ref":"readme.html#acknowledgements"}],"proglang":"elixir","content_type":"text/markdown","producer":{"name":"ex_doc","version":"0.37.3"}}